FieldValues

Trait FieldValues 

pub trait FieldValues: Sealed { }
The values contained or pointed at by an IFD Field.

There are three groups of FieldValues: TiffTypeValues, Offsets and OffsetsToIfds. The first represents a list of values of any given TiffType. The second represents a list of LONG values, each pointing to a specific Datablock. The third represents a list of IFD values, each pointing to an Ifd.

This trait is sealed. It is not possible to implement it outside this crate.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors